.. _frame-schemas:

Frame Schemas
=============

The current ``frame`` schemas:

.. asdf-autoschemas::

   frames/baseframe-1.0.0
   frames/cirs-1.0.0
   frames/fk4-1.0.0
   frames/fk4noeterms-1.0.0
   frames/fk5-1.0.0
   frames/galactic-1.0.0
   frames/galactocentric-1.0.0
   frames/gcrs-1.0.0
   frames/icrs-1.1.0
   frames/itrs-1.0.0
   frames/precessedgeocentric-1.0.0
